@@ -299,7 +299,7 @@ def _download_images(config, images_url):
     #     cwd=config.dirs["images"],
     # )
     current_branch = subprocess.check_output(
-        ["git", "branch", "--show-current"], encoding="utf8", cwd=config.dirs["images"]
+        ["git", "rev-parse", "--abbrev-ref", "HEAD"], encoding="utf8", cwd=config.dirs["images"]
     ).strip()
     if config.ODOO_IMAGES_BRANCH and config.ODOO_IMAGES_BRANCH != current_branch:
         subprocess.check_call(["git", "checkout", config.ODOO_IMAGES_BRANCH])
